@@ -6,8 +6,8 @@
 ;;         Jonathan Arnett <jonathan.arnett@protonmail.com>
 ;;         Greg Pfeil <greg@technomadic.org>
 ;; Created: July 16 2019
-;; Package-Version: 20251006.358
-;; Package-Revision: a71e791e47d0
+;; Package-Version: 20260215.2206
+;; Package-Revision: 9194f46775ab
 ;; Keywords: macos, windows, linux, themes, tools, faces
 ;; URL: https://github.com/LionyxML/auto-dark-emacs
 ;; Package-Requires: ((emacs "24.4"))
@@ -370,7 +370,8 @@ Remove theme change callback registered with D-Bus."
          auto-dark-allow-powershell)
     'powershell)
    ((and (eq system-type 'gnu/linux)
-         (string-match "-[Mm]icrosoft" operating-system-release)
+         (string-match "-[Mm]icrosoft"
+                       (string-trim (shell-command-to-string "uname -r")))
          auto-dark-allow-powershell)
     'powershell)
    ((eq system-type 'windows-nt)
